@@ -29,3 +29,9 @@ class IPOS(Interface):
     """
     part of speech interface
     """
+
+
+class ILexeme(Interface):
+    """
+    lexeme interface
+    """
